Demo data of dec_result
Details
dec_result used in dec_celltype must be a matrix object, each row representing a spot, each column representing a cell type.
Demo data of dec_result
dec_result used in dec_celltype must be a matrix object, each row representing a spot, each column representing a cell type.