Generate pseudo spot st_data with single-cell st_data
Arguments
- st_data
A data.frame or matrix or dgCMatrix containing counts of spatial transcriptomics, each column representing a cell, each row representing a gene.
- st_meta
A data.frame containing coordinate of spatial transcriptomics with three columns,
'cell','x','y', andcelltype.- x_min
Min value of x axis.
- x_res
Resolution of x coordinate.
- x_max
Max value of x axis.
- y_min
Min value of y axis.
- y_res
Resolution of y coordinate.
- y_max
Max value of y axis.