Point plot with LR pair from celltype_sender to celltype_receiver
Usage
plot_lrpair(
object,
celltype_sender,
celltype_receiver,
ligand,
receptor,
color = NULL,
size = 1,
if_plot_density = T,
if_plot_edge = T,
if_show_arrow = T,
arrow_length = 0.05,
plot_cells = NULL
)Arguments
- object
SpaTalk object generated from
dec_celltype.- celltype_sender
Name of celltype_sender.
- celltype_receiver
Name of celltype_receiver.
- ligand
Name of ligand from celltype_sender.
- receptor
Name of receptor from celltype_receiver.
- color
Color for ligand, receptor, and others. Three values.
- size
Point size. Default is
1.- if_plot_density
Whether to plot marginal density plots. Default is
TRUE.- if_plot_edge
Whether to plot edge between neighbors. Default is
TRUE.- if_show_arrow
Whether to show the arrow of the plotted edge. Default is
TRUE.- arrow_length
Arrow length.
- plot_cells
Which cells to plot. Default is all cells. Input a character vector of cell names to plot.