River plot of significantly activated pathways and related downstream genes of receptors.
Source:R/plot.R
plot_path2gene.RdRiver plot of significantly activated pathways and related downstream genes of receptors.
Usage
plot_path2gene(
object,
celltype_sender,
celltype_receiver,
ligand,
receptor,
min_gene_num = 5,
pvalue = 0.5,
color = NULL,
color_flow = "blue"
)Arguments
- object
SpaTalk object generated from
dec_cci.- celltype_sender
Name of celltype_sender.
- celltype_receiver
Name of celltype_receiver.
- ligand
Name of ligand from celltype_sender.
- receptor
Name of receptor from celltype_receiver.
- min_gene_num
Min genes number for each pathway.
- pvalue
P value of the Fisher-exact test.
- color
Color of pathways and genes. Two values.
- color_flow
Color of the flow.