Point plot with spatial distribution of a gene for transcriptomics data
Usage
plot_st_gene(
object,
gene,
size = 1,
color_low = "grey",
color_mid = NULL,
color_high = "blue",
color_midpoint = NULL,
if_use_newmeta = T,
celltype = NULL,
if_plot_others = T
)Arguments
- object
SpaTalk object generated from
dec_celltype.- gene
Symbol of gene, e.g., 'AKT1'.
- size
Point size. Default is
1.- color_low
Color for the lowest value.
- color_mid
Color for the middle value for using
scale_color_gradient2. Default isNULL.- color_high
Color for the highest value.
- color_midpoint
Value for the middle scale. Default is
NULL.- if_use_newmeta
Whether to use newmeta o plot the spatial distribution of gene after
dec_celltypefor spot-based data. Default isTRUE.- celltype
gene in which celltype to plot. Default is
NULL. Setif_use_newmetaTRUE when using this parameter.- if_plot_others
Whether to plot other cells when to use defined
celltype.
Details
Please set if_use_newmeta as FALSE to plot the spatial distribution of gene before dec_celltype for spot-based data.