Skip to contents

Plot scatterpie for spatial transcriptomics data

Usage

plot_st_pie(object, pie_scale = 1, xy_ratio = 1, color = NULL)

Arguments

object

SpaTalk object generated from dec_celltype.

pie_scale

Scale of each pie to plot. Default is 1.

xy_ratio

Ratio of y and x coordinates. Default is 1.

color

Filled of colors for pie plot, length of color must be equal to the number of unique cell types in sc_celltype.