Skip to contents

Plot scatterpie for spot-based ST data

Usage

plot_st_pie_generate(st_meta, pie_scale = 1, xy_ratio = 1, color = NULL)

Arguments

st_meta

st_meta generated from generate_spot

pie_scale

Scale of each pie to plot. Default is 1.

xy_ratio

Ratio of y and x coordinates. Default is 1.

color

Filled of colors for pie plot, length of color must be equal to the number of unique cell types in sc_celltype.