An S4 class containing the data, meta, and results of inferred cell type compositions, LR pairs, and pathways.
Slots
dataA list containing the raw and normalized data.
metaA list containing the raw and new meta data.
paraA list containing the parameters.
coefA matrix containing the results of deconvolution.
cellpairA list containing the cell-cell pairs based on the spatial distance.
distA matrix containing the Euclidean distance among cells.
lrpairA data frame containing the inferred LR pairs.
tfA data frame containing the TFs of receptors.
lr_pathA list containing the lrpairs and pathways.